<template>
  <div>
    <div class="max-w-7xl mx-auto">
      <hr class="my-4" />
      {{ $route.params.id }}
    {{name}}
      <CatBreadcrumb />
      <CatHeader />
      <div class="max-w-7xl mx-auto text-right">
        <h2 class="text-xl font-extrabold text-gray-900">دسته بندی ها</h2>
      </div>
      <div class="relative">
        <VueSlickCarousel
          ref="cat_carousel"
          class="max-w-7xl mx-auto py-4"
          v-bind="cat_lists_setting"
          v-if="GetListProductGroupbyParnet.length > 0"
        >
          <div
            v-for="(ProductGroupbyParnet, index) in GetListProductGroupbyParnet"
            :key="index"
            @click="fetchProductLists(ProductGroupbyParnet.id)"
            class="mx-auto cursor-pointer"
          >
            <CatItem class="mx-2" :cat="ProductGroupbyParnet" />
          </div>
        </VueSlickCarousel>
        <div
          v-if="GetListProductGroupbyParnet.length > 8"
          class="absolute bottom-1/3 left-0 mb-4"
        >
          <div class="text-left">
            <!-- <button
          class="pt-1 px-2"
          variant="link"
          @click="$refs.popular_products_carousel.next()"
        >
          <img src="arrow_right.svg" alt="" srcset="" />
        </button> -->
            <button
              class="pt-1 px-2 xsmall_button"
              @click="$refs.cat_carousel.prev()"
              variant="link"
            >
              <img src="/arrow_gray-cat.svg" alt="" srcset="" />
            </button>
          </div>
        </div>
      </div>

      <Filters />

      <Paginations />

      <div>
        <div class="max-w-2xl mx-auto py-16 sm:py-24 lg:max-w-6xl">
          <h2 class="sr-only">Products</h2>
          <div
            class="grid grid-cols-1 gap-y-10 sm:grid-cols-2 gap-x-6 lg:grid-cols-3 xl:grid-cols-4 xl:gap-x-8"
          >
            <div
              class="group"
              v-for="(GetProductList, index) in GetProductLists"
              :key="index"
              v-on:click="productCat(GetProductList)"
            >
              <CatProductList :productlistsCat="GetProductList" />
            </div>
          </div>
        </div>
      </div>
      <Paginations />
      <baseApplication />
      <baseServices />
      <ProductQuickview
        :productItemData="productItemData"
        :productItemData1="productItemData1"
        :show="ShowProductQuickview"
        @close="ShowProductQuickview = $event"
      />
    </div>
  </div>
</template>

<script>
import VueSlickCarousel from 'vue-slick-carousel'
import 'vue-slick-carousel/dist/vue-slick-carousel.css'
import 'vue-slick-carousel/dist/vue-slick-carousel-theme.css'
import Filters from '../../components/cat/filters.vue'
import Paginations from '../../components/cat/paginations.vue'
import ProductQuickview from '../../components/base/productQuickview.vue'

import { mapState, mapGetters, mapActions, mapMutations } from 'vuex'

const pages = [
  { name: 'سوپر مارکت', href: '#', current: false },
  { name: 'تنقلات', href: '#', current: true },
]

export default {
  components: {
    VueSlickCarousel,
    Filters,
    Paginations,
    ProductQuickview,
  },
  watch: {
    '$route.params.id': {
      handler: function (groupID) {
        this.$store.dispatch('products/fetchProductLists', groupID)
        this.$store.dispatch('products/fetchListProductsGroupbyParnet', groupID)
      },
      deep: true,
      immediate: true,
    },
  },

  computed: {
    ...mapGetters({
      GetListProductGroupbyParnet: 'products/GetListProductsGroupbyParnetCat',
      GetProductLists: 'products/GetProductLists',
    }),
  },
  created() {
    this.fetchProductLists()
    this.fetchListProductsGroupbyParnet()
  },

  methods: {
    productCat(event) {
      this.productItemData = event
      console.log(event)
      this.ShowProductQuickview = true
    },
    fetchProductLists(id) {
      if (id == null) {
        this.$store.dispatch(
          'products/fetchProductLists',
          this.$route.params.id
        )
      } else {
        this.$store.dispatch('products/fetchProductLists', id)
      }
    },
    fetchListProductsGroupbyParnet() {
      this.$store.dispatch(
        'products/fetchListProductsGroupbyParnet',
        this.$route.params.id
      )
    },
  },

  data() {
    return {
      pages,
      productItemData: {},
      productItemData1: {},
      ShowProductQuickview: false,
      cat_lists_setting: {
        infinite: true,
        arrows: false,
        speed: 500,
        slidesToShow: 8,
        slidesToScroll: 1,
        touchThreshold: 1,
        initialSlide: 0,
        autoplay: true,
        pauseOnFocus: true,
        pauseOnHover: true,
        // focusOnSelect: true,
        responsive: [
          {
            breakpoint: 1024,
            settings: {
              slidesToShow: 3,
              slidesToScroll: 3,
              infinite: true,
              dots: true,
            },
          },
          {
            breakpoint: 600,
            settings: {
              slidesToShow: 4,
              slidesToScroll: 2,
              initialSlide: 2,
            },
          },
          {
            breakpoint: 480,
            settings: {
              slidesToShow: 3,
              slidesToScroll: 1,
            },
          },
        ],
      },
    }
  },
}
</script>

<style lang="scss" scoped>
// a.nuxt-link-active {
//   font-weight: bold;
// }
// /* exact link will show the primary color for only the exact matching link */
// a.nuxt-link-exact-active {
//   background-color: #ed3d53;
//   color: white;
// }
</style>
